// java wrapper for vtkDataObjectReader object
//

package vtk;
import vtk.*;

public class vtkDataObjectReader extends vtkDataReader
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetOutput_2();
  public vtkDataObject GetOutput() {
    long temp = GetOutput_2();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutput_3(int id0);
  public vtkDataObject GetOutput(int id0) {
    long temp = GetOutput_3(id0);

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetOutput_4(vtkDataObject id0);
  public void SetOutput(vtkDataObject id0)
    { SetOutput_4(id0); }

  public vtkDataObjectReader() { super(); }

  public vtkDataObjectReader(long id) { super(id); }
  public native long   VTKInit();

}
